==> jboss-msc-1.2.1.Final-source-release.zip: jboss-msc-1.2.1.Final/src/main/java/org/jboss/msc/service/AbstractService.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.msc.service;

/**
 * An abstract service class which provides default implementations.
 *
 * @param <T> the value type
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public abstract class AbstractService<T> implements Service<T> {

    /** {@inheritDoc}  This implementation does nothing. */
    public void start(final StartContext context) throws StartException {
    }

    /** {@inheritDoc}  This implementation does nothing. */
    public void stop(final StopContext context) {
    }

    /** {@inheritDoc}  This implementation returns {@code null}. */
    public T getValue() throws IllegalStateException {
        return null;
    }
}

==> jboss-msc-1.4.13.Final-source-release.zip: jboss-msc-1.4.13.Final/src/main/java/org/jboss/msc/service/AbstractService.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2021, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.msc.service;

/**
 * An abstract service class which provides default implementations.
 *
 * @param <T> the value type
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 * @deprecated use {@link org.jboss.msc.Service} instead.
 * This class will be removed in a future release.
 */
@Deprecated
public abstract class AbstractService<T> implements Service<T> {

    /** {@inheritDoc}  This implementation does nothing. */
    public void start(final StartContext context) throws StartException {
    }

    /** {@inheritDoc}  This implementation does nothing. */
    public void stop(final StopContext context) {
    }

    /** {@inheritDoc}  This implementation returns {@code null}. */
    public T getValue() throws IllegalStateException {
        return null;
    }
}
